@@ -1,6 +1,6 @@
 package CPAN::Perl::Releases;
 {
-  $CPAN::Perl::Releases::VERSION = '1.32';
+  $CPAN::Perl::Releases::VERSION = '1.34';
 }
 
 #ABSTRACT: Mapping Perl releases on CPAN to the location of the tarballs
@@ -407,6 +407,10 @@ our $data =
     "tar.bz2" => "R/RJ/RJBS/perl-5.18.1-RC3.tar.bz2",
     "tar.gz" => "R/RJ/RJBS/perl-5.18.1-RC3.tar.gz",
   },
+  "5.18.1" => {
+    "tar.bz2" => "R/RJ/RJBS/perl-5.18.1.tar.bz2",
+    "tar.gz" => "R/RJ/RJBS/perl-5.18.1.tar.gz",
+  },
   "5.19.0" => {
     "tar.bz2" => "R/RJ/RJBS/perl-5.19.0.tar.bz2",
     "tar.gz" => "R/RJ/RJBS/perl-5.19.0.tar.gz",
@@ -531,7 +535,7 @@ CPAN::Perl::Releases - Mapping Perl releases on CPAN to the location of the tarb
 
 =head1 VERSION
 
-version 1.32
+version 1.34
 
 =head1 SYNOPSIS
 
